@@ -9,7 +9,7 @@ import { Chip, Tooltip } from '@material-ui/core';
 import { CellMetadataEditorDialog } from './CellMetadataEditorDialog';
 import { ISettingRegistry } from '@jupyterlab/settingregistry';
 import { getTransformerEnabled } from './../settings';
-import { fetchTransformerStattes, issueTransformerStatesChange, addStatesChangeListener, ITransformerStates } from './../states'
+import { fetchTransformerStates, issueTransformerStatesChange, addStatesChangeListener, ITransformerStates } from './../states'
 import { showCurrentActiveCellTransformerWidget } from './../notebook'
 import CellUtils from './../lib/CellUtils';
 import * as nbformat from '@jupyterlab/nbformat';
@@ -34,43 +34,43 @@ const CELL_TYPES: any[] = [
         value: CELL_TYPE_REQUIREMENTS,
         label: 'Requirements',
         helpText: 'The code in this cell will be parsed as requirements packages and install in system.',
-        chipColor: 'a32626'
+        chipColor: '84ffff'
     },
     {
         value: CELL_TYPE_PREPROCESSOR,
         label: 'Pre processor',
         helpText: 'The code in this cell will be parsed as preprocessor for the predict function of deployed model.',
-        chipColor: 'ee7a1a'
+        chipColor: 'b9f6ca'
     },
     {
         value: CELL_TYPE_POSTPROCESSOR,
         label: 'Post processor',
         helpText: 'The code in this cell will be parsed as postprocessor for the predict function of deployed model.',
-        chipColor: '773d0d'
+        chipColor: '69f0ae'
     },
     {
         value: 'functions',
         label: 'Extra functions',
         helpText: 'The code in this cell will be parsed as referenced function for the preprocessor or postprocessor.',
-        chipColor: 'a32626'
+        chipColor: 'ccff90'
     },
     {
         value: CELL_TYPE_CVAT_INFO,
         label: 'CVAT Info',
         helpText: 'The code in this cell will be parsed as cvat_info callback function.',
-        chipColor: 'a32626'
+        chipColor: 'c6ff00'
     },
     {
         value: CELL_TYPE_CVAT_PREPROCESSOR,
         label: 'CVAT Pre processor',
         helpText: 'The code in this cell will be parsed as CVAT preprocessor for the predict function of deployed model.',
-        chipColor: 'ee7a1a'
+        chipColor: 'f4ff81'
     },
     {
         value: CELL_TYPE_CVAT_POSTPROCESSOR,
         label: 'CVAT Post processor',
         helpText: 'The code in this cell will be parsed as CVAT postprocessor for the predict function of deployed model.',
-        chipColor: '773d0d'
+        chipColor: 'eeff41'
     }
 ];
 
@@ -161,10 +161,10 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
 
     constructor(props: IProps) {
         super(props);
-        this.transformerStates = fetchTransformerStattes();
+        this.transformerStates = fetchTransformerStates(this.props.notebookPanel.id);
         this.updateLocalTransformerStates(props.transformerTag, true);
-        addStatesChangeListener(this.onStatesChangeCallback);
-        issueTransformerStatesChange(this.props.cellId, this.transformerStates);
+        addStatesChangeListener(this.props.notebookPanel.id, this.onStatesChangeCallback);
+        issueTransformerStatesChange(this.props.notebookPanel.id, this.props.cellId, this.transformerStates);
         const defaultState: IState = {
             transformerTag: props.transformerTag?props.transformerTag : CELL_TYPE_NA,
             isChipVisible: RESERVED_CELL_NAMES.includes(props.transformerTag)? true: false,
@@ -266,7 +266,7 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
         if(value !== this.state.transformerTag) {
             this.updateLocalTransformerStates(this.state.transformerTag, false);
             this.updateLocalTransformerStates(value, true);
-            issueTransformerStatesChange(this.props.cellId, this.transformerStates);
+            issueTransformerStatesChange(this.props.notebookPanel.id, this.props.cellId, this.transformerStates);
             if (RESERVED_CELL_NAMES.includes(value)) {
                 this.setState({ transformerTag: value });
             } else if(CELL_TYPE_NA === value) {
@@ -409,7 +409,7 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
 
     removeCellTagInNotebookFile = () => {
         this.updateLocalTransformerStates(this.state.transformerTag, false);
-        issueTransformerStatesChange(this.props.cellId, this.transformerStates);
+        issueTransformerStatesChange(this.props.notebookPanel.id, this.props.cellId, this.transformerStates);
         TagsUtils.resetCellTransformerTag(
             this.props.notebookPanel,
             this.props.notebookPanel.content.activeCellIndex,
@@ -522,6 +522,7 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
                             key={ this.state.transformerTag }
                             label={ this.state.transformerTag }
                             onClick={() => this.onChipClick()}
+                            style={{ backgroundColor: `#${RESERVED_CELL_NAMES_CHIP_COLOR[this.state.transformerTag]}` }}
                         />
                     </Tooltip>
                 </div>
