@@ -5,7 +5,7 @@ import { executeRpc, globalUnhandledRejection } from './../lib/RPCUtils';
 import NotebookUtils from './../lib/NotebookUtils';
 import { Kernel } from '@jupyterlab/services';
 import { ISettingRegistry } from '@jupyterlab/settingregistry';
-import { getTransformerEnabled, setTransformerEnabled, getTransformerProxyUrl, addStatusChangeListener, StatusContent, triggerStatusUpdate, setTransformerNotebookPath } from './../settings';
+import { getTransformerEnabled, setTransformerEnabled, addStatusChangeListener, StatusContent, triggerStatusUpdate, setTransformerNotebookPath } from './../settings';
 import { saveTransformerNotebook } from './../notebook';
 import {
     Switch,
@@ -172,7 +172,7 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
         });
         saveTransformerNotebook();
 
-        let proxyUrl: string = getTransformerProxyUrl();
+        let proxyUrl: string = this.state.proxyUrl;
         if(! proxyUrl) {
             this.renderDialog({
                 title: 'Error',
@@ -218,7 +218,7 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
 
     doResetTransformer = async () => {
         console.log("doResetTransformer");
-        let proxyUrl: string = getTransformerProxyUrl();
+        let proxyUrl: string = this.state.proxyUrl;
         if(! proxyUrl) {
             this.renderDialog({
                 title: 'Error',
@@ -407,7 +407,9 @@ export class TransformerLeftPanel extends React.Component<IProps, IState> {
                             </Typography>
                             <Collapse in={this.state.showResetTransformerDescription} timeout="auto" unmountOnExit>
                                 <Typography variant="body1" gutterBottom style={{ color: theme.transformer.headers.main }}>
-                                    Reset <strong style={{ fontWeight: '600' }}>transformer.ipynb</strong>, this action also reset the pre and post processors for model inference.
+                                    <strong style={{ fontWeight: '600' }}>Reset {this.state.transformerNotebookPath? this.state.transformerNotebookPath: 'transformer.ipynb'}</strong>
+                                    <br />
+                                    This action also reset the pre and post processors for model inference.
                                 </Typography>
                             </Collapse>
                             <div className="input-container add-button">
